DatecsPrinter class

Constructors

DatecsPrinter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

disconnect → Future<bool>
no setter
getListBluetoothDevice → Future<List>
no setter
platformVersion → Future<String>
no setter
printTest → Future<void>
no setter

Static Methods

connectBluetooth(String address) → Future<bool>
printText(List<String> args) → Future<bool>